package live

import (
	"github.com/gin-gonic/gin"
	"github.com/golangkit/formatime"
	"github.com/shopspring/decimal"
	"live/app/common"
	"live/app/lib"
	"live/app/lib/back"
	"live/app/lib/tools"
	"live/app/model/live"
	"time"
)

type Data struct {
}

type replyList struct {
	Id      uint  `json:"id"`
	StartAt int64 `json:"startAt"`
	EndAt   int64 `json:"endAt"`
}

// @Title 场次列表
func (d *Data) List(c *gin.Context) {
	args := lib.Page{}
	if err := tools.ParseParams(&args, c); err != nil {
		back.Fail(c, err.Error())
		return
	}
	userId := common.GetUserId(c)
	liveItems := (&live.LiveItem{}).GetUserListFinish(userId, args.GetStart(), args.GetLimit())
	reply := []replyList{}
	for _, item := range liveItems {
		reply = append(reply, replyList{
			Id:      item.Id,
			StartAt: item.StartAt.Time.Unix(),
			EndAt:   item.EndAt.Time.Unix(),
		})
	}
	back.Suc(c, "操作成功", reply)
}

type argsInfo struct {
	Id uint `json:"id" form:"id"`
}

type replyInfo struct {
	Id                 uint            `json:"id"`
	StartAt            int64           `json:"startAt"`
	EndAt              int64           `json:"endAt"`
	SalesVolume        decimal.Decimal `json:"salesVolume"`
	AnticipatedRevenue decimal.Decimal `json:"anticipatedRevenue"`
	Buy                int             `json:"buy"`
	Look               int             `json:"look"`
	Praise             int             `json:"praise"`
	Fans               int             `json:"fans"`
}

// @Title 场次详情
func (d *Data) Info(c *gin.Context) {
	args := argsInfo{}
	if err := tools.ParseParams(&args, c); err != nil {
		back.Fail(c, err.Error())
		return
	}
	if args.Id <= 0 {
		back.Fail(c, "参数错误")
		return
	}
	liveItem := (&live.LiveItem{}).FindById(args.Id)
	if liveItem.Id <= 0 {
		back.Fail(c, "参数错误")
		return
	}
	liveData := (&live.LiveData{}).GetByLiveItemId(liveItem.Id)
	reply := replyInfo{
		Id:                 liveItem.Id,
		StartAt:            liveItem.StartAt.Time.Unix(),
		EndAt:              liveItem.EndAt.Time.Unix(),
		SalesVolume:        liveData.SalesVolume,
		AnticipatedRevenue: liveData.AnticipatedRevenue,
		Buy:                liveData.Buy,
		Look:               liveData.Look,
		Praise:             liveData.Praise,
		Fans:               liveData.Fans,
	}
	back.Suc(c, "操作成功", reply)
}

type argsCount struct {
	Day int `json:"day" form:"day"`
}

type replyCount struct {
	Look                   int                 `json:"look"`
	SalesVolume            decimal.Decimal     `json:"salesVolume"`
	AnticipatedRevenue     decimal.Decimal     `json:"anticipatedRevenue"`
	Buy                    int                 `json:"buy"`
	Praise                 int                 `json:"praise"`
	Fans                   int                 `json:"fans"`
	Count                  int                 `json:"count"`
	Duration               int                 `json:"duration"`
	DatePrise              []DayCountItem      `json:"datePrise"`
	DateLook               []DayCountItem      `json:"dateLook"`
	DateFans               []DayCountItem      `json:"dateFans"`
	DateBuy                []DayCountItem      `json:"dateBuy"`
	DateSalesVolume        []DayCountItemPrice `json:"dateSalesVolume"`
	DateAnticipatedRevenue []DayCountItemPrice `json:"dateAnticipatedRevenue"`
}
type DayCountItem struct {
	Date  string `json:"date"`
	Count int    `json:"count"`
}
type DayCountItemPrice struct {
	Date  string          `json:"date"`
	Count decimal.Decimal `json:"count"`
}

// @Title 统计数据
func (d *Data) Count(c *gin.Context) {
	args := argsCount{}
	if err := tools.ParseParams(&args, c); err != nil {
		back.Fail(c, err.Error())
		return
	}
	if args.Day <= 0 {
		back.Fail(c, "参数错误")
		return
	}
	userId := common.GetUserId(c)
	timeStart, _ := time.ParseInLocation("2006-01-02", time.Now().Add(time.Hour*-24*time.Duration(args.Day-1)).Format("2006-01-02"), time.Local)
	liveItems := (&live.LiveItem{}).GetListByTime(userId, formatime.NewSecondFrom(timeStart), formatime.NewSecondNow())
	liveItemIds := []uint{}
	liveItemMap := map[uint]live.LiveItem{}
	for _, item := range liveItems {
		liveItemIds = append(liveItemIds, item.Id)
		liveItemMap[item.Id] = item
	}
	liveDatas := (&live.LiveData{}).GetByLiveItemIds(liveItemIds)
	reply := replyCount{
		Count:                  len(liveDatas),
		DatePrise:              []DayCountItem{},
		DateLook:               []DayCountItem{},
		DateFans:               []DayCountItem{},
		DateBuy:                []DayCountItem{},
		DateSalesVolume:        []DayCountItemPrice{},
		DateAnticipatedRevenue: []DayCountItemPrice{},
	}
	praiseMap := map[string]int{}
	lookMap := map[string]int{}
	fansMap := map[string]int{}
	buyMap := map[string]int{}
	salesVolumeMap := map[string]decimal.Decimal{}
	anticipatedRevenueMap := map[string]decimal.Decimal{}
	for _, data := range liveDatas {
		reply.SalesVolume = reply.SalesVolume.Add(data.SalesVolume)
		reply.AnticipatedRevenue = reply.AnticipatedRevenue.Add(data.AnticipatedRevenue)
		reply.Buy += data.Buy
		reply.Look += data.Look
		reply.Praise += data.Praise
		reply.Fans += data.Fans
		reply.Duration += data.Duration
		keyDay := liveItemMap[data.LiveItemId].StartAt.Time.Format("01-02")
		praiseMap[keyDay] += data.Praise
		lookMap[keyDay] += data.Look
		fansMap[keyDay] += data.Fans
		buyMap[keyDay] += data.Buy
		salesVolumeMap[keyDay] = salesVolumeMap[keyDay].Add(data.SalesVolume)
		anticipatedRevenueMap[keyDay] = anticipatedRevenueMap[keyDay].Add(data.AnticipatedRevenue)
	}
	for i := 0; i < args.Day; i++ {
		date := time.Now().Add(time.Hour * -24 * time.Duration(i)).Format("01-02")
		reply.DatePrise = append(reply.DatePrise, DayCountItem{
			Date:  date,
			Count: praiseMap[date],
		})
		reply.DateLook = append(reply.DateLook, DayCountItem{
			Date:  date,
			Count: lookMap[date],
		})
		reply.DateFans = append(reply.DateFans, DayCountItem{
			Date:  date,
			Count: fansMap[date],
		})
		reply.DateBuy = append(reply.DateBuy, DayCountItem{
			Date:  date,
			Count: buyMap[date],
		})
		reply.DateSalesVolume = append(reply.DateSalesVolume, DayCountItemPrice{
			Date:  date,
			Count: salesVolumeMap[date],
		})
		reply.DateAnticipatedRevenue = append(reply.DateAnticipatedRevenue, DayCountItemPrice{
			Date:  date,
			Count: anticipatedRevenueMap[date],
		})
	}
	back.Suc(c, "操作成功", reply)
}
