package live

import (
	"fmt"
	"github.com/gin-gonic/gin"
	"live/app/common"
	"live/app/lib/back"
	"live/app/lib/recook"
	"live/app/lib/tools"
	"live/app/logic/live"
	live2 "live/app/model/live"
)

type Im struct {
}

// @Title 已登录账号的im
func (i *Im) LoginInfo(c *gin.Context) {
	userId := common.GetUserId(c)
	err, info := live.ImLogic.LoginUserInfo(userId)
	if err != nil {
		back.Fail(c, err.Error())
		return
	}
	back.Suc(c, "操作成功", info)
}

// @Title 未登录账号im获取
func (i *Im) NoLoginInfo(c *gin.Context) {
	err, info := live.ImLogic.NoLoginUserInfo()
	if err != nil {
		back.Fail(c, err.Error())
		return
	}
	back.Suc(c, "操作成功", info)
}

type argsGoodsId struct {
	LiveItemId uint `json:"liveItemId" form:"liveItemId"`
	GoodsId    uint `json:"goodsId" form:"goodsId"`
}

// @Title 购物通知
func (i *Im) BuyGoods(c *gin.Context) {
	args := argsGoodsId{}
	if err := tools.ParseParams(&args, c); err != nil {
		back.Fail(c, err.Error())
		return
	}
	if args.GoodsId <= 0 || args.LiveItemId <= 0 {
		back.Fail(c, "参数错误")
		return
	}
	userId := common.GetUserId(c)
	liveItem := (&live2.LiveItem{}).FindById(args.LiveItemId)
	if liveItem.Id <= 0 {
		back.Fail(c, "参数错误")
		return
	}
	users, _ := recook.User.GetUsers([]uint{userId})
	if len(*users) == 0 {
		back.Fail(c, "网络异常")
		return
	}
	live.ImLogic.SendLiveGroupMessage(liveItem.RoomId, live.LiveGroupMsgTypeBuyGoods, gin.H{
		"content": fmt.Sprintf("用户%s正在购买", common.HideNickname((*users)[0].Nickname)),
	})
	back.Suc(c, "操作成功", nil)
}
