package live

import (
	"github.com/gin-gonic/gin"
	"github.com/shopspring/decimal"
	"live/app/common"
	"live/app/lib"
	"live/app/lib/back"
	"live/app/lib/config"
	"live/app/lib/recook"
	"live/app/lib/tencent"
	"live/app/lib/tools"
	"live/app/logic/live"
	live2 "live/app/model/live"
	"live/app/model/topic"
	"live/app/model/user"
	"strconv"
	"strings"
)

type Live struct {
}

type replyLists struct {
	Title         string `json:"title"`
	Id            uint   `json:"id"`
	Cover         string `json:"cover"`
	Nickname      string `json:"nickname"`
	HeadImgUrl    string `json:"headImgUrl"`
	Look          int    `json:"look"`
	GoodsName     string `json:"goodsName"`
	MainPhotoURL  string `json:"mainPhotoUrl"`
	OriginalPrice string `json:"originalPrice"`
	DiscountPrice string `json:"discountPrice"`
	Praise        int    `json:"praise"`
	IsLive        int    `json:"isLive"`
}

func (l *Live) List(c *gin.Context) {
	args := lib.Page{}
	if err := tools.ParseParams(&args, c); err != nil {
		back.Fail(c, err.Error())
		return
	}
	result := []replyLists{}
	lists := live.LiveLogic.Lists(args)
	if len(lists) > 0 {
		userIds := []uint{}
		liveItemIds := []uint{}
		mainGoodsIds := []uint{}
		for _, list := range lists {
			userIds = append(userIds, list.UserId)
			liveItemIds = append(liveItemIds, list.Id)
			mainGoodsIds = append(mainGoodsIds, list.MainGoodsId)
		}
		users, _ := recook.User.GetUsers(userIds)
		userMap := map[uint]recook.ReplyUserItem{}
		for _, item := range *users {
			userMap[item.UserId] = item
		}
		liveData := &live2.LiveData{}
		liveDatas := liveData.GetByLiveItemIds(liveItemIds)
		liveDataMap := map[uint]live2.LiveData{}
		for _, item := range liveDatas {
			liveDataMap[item.LiveItemId] = item
		}

		goodsInfos, _ := recook.Goods.GetListByIds(mainGoodsIds)
		goodsMap := map[uint]recook.GoodsInfo{}
		for _, info := range *goodsInfos {
			goodsMap[info.ID] = info
		}

		for _, list := range lists {
			result = append(result, replyLists{
				Id:            list.Id,
				Title:         list.Title,
				Cover:         list.Cover,
				IsLive:        list.Status,
				Nickname:      userMap[list.UserId].Nickname,
				HeadImgUrl:    userMap[list.UserId].HeadImgUrl,
				Look:          liveDataMap[list.Id].Look,
				Praise:        liveDataMap[list.Id].Praise,
				GoodsName:     goodsMap[list.MainGoodsId].GoodsName,
				MainPhotoURL:  goodsMap[list.MainGoodsId].MainPhotoURL,
				OriginalPrice: goodsMap[list.MainGoodsId].OriginalPrice,
				DiscountPrice: goodsMap[list.MainGoodsId].DiscountPrice,
			})
		}
	}
	back.Suc(c, "操作成功", result)
}

// @Title live sdk License
func (l *Live) License(c *gin.Context) {
	back.Suc(c, "操作成功", gin.H{
		"key":        config.Config.Section("tencent.live.license").Key("key").String(),
		"licenseUrl": config.Config.Section("tencent.live.license").Key("licenseUrl").String(),
	})
}

type liveInfo struct {
	LiveItemId uint        `json:"liveItemId"`
	PushUrl    string      `json:"pushUrl"`
	GroupId    string      `json:"groupId"`
	Nickname   string      `json:"nickname"`
	HeadImgUrl string      `json:"headImgUrl"`
	UserId     uint        `json:"userId"`
	Praise     int         `json:"praise"`
	GoodsLists []GoodsItem `json:"goodsLists"`
	Title      string      `json:"title"`
	Topic      uint        `json:"topic"`
	IsFirst    int         `json:"isFirst"`
}

func (l *Live) Info(c *gin.Context) {
	userId := common.GetUserId(c)
	liveRoom := (&live2.LiveRoom{}).GetLiveByUserId(userId)
	userData := &user.UserData{}
	udata := userData.GetByUserId(userId)
	isFirst := 1
	if udata.LiveTreaty == 1 {
		isFirst = 0
	}
	liveItem := (&live2.LiveItem{}).GetLiveItemIng(userId)
	if liveItem.Id <= 0 {
		back.Suc(c, "", liveInfo{
			IsFirst: isFirst,
		})
		return
	}
	users, err := recook.User.GetUsers([]uint{liveItem.UserId})
	if err != nil || len(*users) == 0 {
		back.Fail(c, "网络异常")
		return
	}
	liveData := (&live2.LiveData{}).GetByLiveItemId(liveItem.Id)

	itemGoods := (&live2.LiveGoods{}).GetGoodsByLiveItemId(liveItem.Id)
	goodsIds := []uint{}
	for _, item := range itemGoods {
		goodsIds = append(goodsIds, item.GoodsId)
	}
	goodsInfos, err := recook.Goods.GetListByIds(goodsIds)
	if err != nil {
		back.Fail(c, "网络异常")
		return
	}
	goodsInfoMap := map[uint]recook.GoodsInfo{}
	for _, info := range *goodsInfos {
		goodsInfoMap[info.ID] = info
	}
	goodsList := []GoodsItem{}
	for _, item := range itemGoods {
		goodsList = append(goodsList, GoodsItem{
			GoodsInfo: goodsInfoMap[item.GoodsId],
			IsExplain: item.IsExplain,
		})
	}

	topicInfo := (&topic.Topic{}).GetById(liveItem.Topic)

	reply := liveInfo{
		LiveItemId: liveItem.Id,
		PushUrl:    tencent.Live.GetPushUrl(liveRoom.StreamName, liveItem.Id),
		Nickname:   (*users)[0].Nickname,
		HeadImgUrl: (*users)[0].HeadImgUrl,
		GroupId:    liveRoom.GroupId,
		UserId:     liveItem.UserId,
		Praise:     liveData.Praise,
		GoodsLists: goodsList,
		Topic:      liveItem.Topic,
		Title:      topicInfo.Title,
		IsFirst:    isFirst,
	}
	back.Suc(c, "操作成功", reply)
}

// @Title 同意协议
func (l *Live) Agree(c *gin.Context) {
	userId := common.GetUserId(c)
	userDataModel := &user.UserData{}
	udata := userDataModel.GetByUserId(userId)
	if udata.Id > 0 {
		if udata.LiveTreaty != user.LiveTreatyAgree {
			row := userDataModel.Treaty(userId)
			if row <= 0 {
				back.Fail(c, "操作失败")
				return
			}
		}
	} else {
		data := user.UserData{
			UserId:     userId,
			LiveTreaty: user.LiveTreatyAgree,
		}
		userDataModel.Create(&data)
		if data.Id <= 0 {
			back.Fail(c, "操作失败")
			return
		}
	}
	back.Suc(c, "操作成功", "")
}

type userFolowLive struct {
	Id     uint `json:"id"`
	UserId uint `json:"userId"`
	Status int  `json:"status"`
}

type replyFollowList struct {
	Nickname   string `json:"nickname"`
	HeadImgUrl string `json:"headImgUrl"`
	UserId     uint   `json:"userId"`
	LiveItemId uint   `json:"liveItemId"`
	IsLive     int    `json:"isLive"`
}

// @Title 关注直播列表
func (l *Live) FollowList(c *gin.Context) {
	args := lib.Page{}
	if err := tools.ParseParams(&args, c); err != nil {
		back.Fail(c, err.Error())
		return
	}
	userId := common.GetUserId(c)

	userFollows := (&user.UserFollow{}).GetListByUserId(userId, args.GetStart(), args.GetLimit())
	followUserIds := []uint{}
	for _, follow := range *userFollows {
		followUserIds = append(followUserIds, follow.FollowUserId)
	}
	liveItems := (&live2.LiveItem{}).GetUsersLiveItem(followUserIds)

	liveItemMap := map[uint]live2.LiveItem{}
	for _, item := range liveItems {
		liveItemMap[item.UserId] = item
	}
	users, _ := recook.User.GetUsers(followUserIds)
	userMap := map[uint]recook.ReplyUserItem{}
	for _, item := range *users {
		userMap[item.UserId] = item
	}
	replay := []replyFollowList{}
	for _, list := range *userFollows {
		isLive := 0
		liveItemId := uint(0)
		if item, ok := liveItemMap[list.FollowUserId]; ok {
			isLive = 1
			liveItemId = item.Id
		}
		replay = append(replay, replyFollowList{
			Nickname:   userMap[list.FollowUserId].Nickname,
			HeadImgUrl: userMap[list.FollowUserId].HeadImgUrl,
			UserId:     list.FollowUserId,
			LiveItemId: liveItemId,
			IsLive:     isLive,
		})
	}

	back.Suc(c, "操作成功", replay)
}

type argsStart struct {
	Title    string `json:"title" form:"title"`
	Cover    string `json:"cover" form:"cover"`
	Topic    uint   `json:"" form:"topic"`
	GoodsIds []uint `json:"goodsIds" form:"goodsIds"`
}

// @Title 开播
func (l *Live) Start(c *gin.Context) {
	args := argsStart{}
	if err := tools.ParseParams(&args, c); err != nil {
		back.Fail(c, err.Error())
		return
	}
	if args.Title == "" || len(args.GoodsIds) == 0 {
		back.Fail(c, "参数错误")
		return
	}
	userId := common.GetUserId(c)
	start, err := live.LiveLogic.Start(userId, args.Title, args.Cover, args.Topic, args.GoodsIds)
	if err != nil {
		back.Fail(c, err.Error())
		return
	}
	back.Suc(c, "操作成功", start)
}

type argsLiveId struct {
	Id uint `json:"id" form:"id"`
}

type replyLiveInfo struct {
	Nickname     string      `json:"nickname"`
	HeadImgUrl   string      `json:"headImgUrl"`
	PlayUrl      string      `json:"playUrl"`
	UserId       uint        `json:"userId"`
	Id           uint        `json:"id"`
	IsFollow     int         `json:"isFollow"`
	IsPraise     int         `json:"isPraise"`
	Praise       int         `json:"praise"`
	GoodsLists   []GoodsItem `json:"goodsLists"`
	GroupId      string      `json:"groupId"`
	Topic        uint        `json:"topic"`
	Title        string      `json:"title"`
	Cover        string      `json:"cover"`
	InvitationNo string      `json:"invitationNo"`
}

type GoodsItem struct {
	recook.GoodsInfo
	IsExplain uint `json:"isExplain"`
}

// @Title 直播信息
func (l *Live) LiveInfo(c *gin.Context) {
	args := argsLiveId{}
	if err := tools.ParseParams(&args, c); err != nil {
		back.Fail(c, err.Error())
		return
	}
	if args.Id <= 0 {
		back.Fail(c, "参数错误")
		return
	}
	liveItemModel := &live2.LiveItem{}
	liveItem := liveItemModel.FindById(args.Id)
	if liveItem.Id <= 0 {
		back.Fail(c, "直播间错误")
		return
	}
	if liveItem.Status == live2.LIVE_STATUS_finish {
		back.Fail(c, "直播已结束")
		return
	}
	users, err := recook.User.GetUsers([]uint{liveItem.UserId})
	if err != nil || len(*users) == 0 {
		back.Fail(c, "网络异常")
		return
	}
	isFollow := 0
	isPraise := 0
	userId := common.GetUserId(c)
	if userId > 0 {
		userFollow := (&user.UserFollow{}).GetByUserIdAndFollowId(userId, liveItem.UserId)
		if userFollow.Id > 0 && userFollow.IsDel == 0 {
			isFollow = 1
		}

		userLivePraise := (&user.UserLivePraise{}).GetPraiseByUserIdAndLiveItemId(userId, liveItem.Id)
		if userLivePraise.Id > 0 {
			isPraise = 1
		}
	}

	liveData := (&live2.LiveData{}).GetByLiveItemId(liveItem.Id)
	liveRoom := (&live2.LiveRoom{}).GetLiveByUserId(liveItem.UserId)

	itemGoods := (&live2.LiveGoods{}).GetGoodsByLiveItemId(liveItem.Id)
	goodsIds := []uint{}
	for _, item := range itemGoods {
		goodsIds = append(goodsIds, item.GoodsId)
	}
	goodsInfos, err := recook.Goods.GetListByIds(goodsIds)
	if err != nil {
		back.Fail(c, "网络异常")
		return
	}
	goodsInfoMap := map[uint]recook.GoodsInfo{}
	for _, info := range *goodsInfos {
		goodsInfoMap[info.ID] = info
	}
	goodsList := []GoodsItem{}
	for _, item := range itemGoods {
		goodsList = append(goodsList, GoodsItem{
			GoodsInfo: goodsInfoMap[item.GoodsId],
			IsExplain: item.IsExplain,
		})
	}

	// 观看直播，进行统计
	live.DataLogic.Look(userId, liveItem.Id)
	topicInfo := (&topic.Topic{}).GetById(liveItem.Topic)

	reply := replyLiveInfo{
		Nickname:     (*users)[0].Nickname,
		HeadImgUrl:   (*users)[0].HeadImgUrl,
		InvitationNo: (*users)[0].InvitationNo,
		PlayUrl:      tencent.Live.GetPlayUrl(liveRoom.StreamName, liveItem.Id),
		GroupId:      liveRoom.GroupId,
		UserId:       liveItem.UserId,
		Id:           liveItem.Id,
		Cover:        liveItem.Cover,
		IsFollow:     isFollow,
		IsPraise:     isPraise,
		Praise:       liveData.Praise,
		GoodsLists:   goodsList,
		Topic:        liveItem.Topic,
		Title:        topicInfo.Title,
	}
	back.Suc(c, "操作成功", reply)
}

// @Title 点播
func (l *Live) VideoInfo(c *gin.Context) {
	args := argsLiveId{}
	if err := tools.ParseParams(&args, c); err != nil {
		back.Fail(c, err.Error())
		return
	}
	if args.Id <= 0 {
		back.Fail(c, "参数错误")
		return
	}
	liveItemModel := &live2.LiveItem{}
	liveItem := liveItemModel.FindById(args.Id)
	if liveItem.Id <= 0 {
		back.Fail(c, "直播间错误")
		return
	}
	if liveItem.Status != live2.LIVE_STATUS_finish {
		back.Fail(c, "参数错误")
		return
	}
	users, err := recook.User.GetUsers([]uint{liveItem.UserId})
	if err != nil || len(*users) == 0 {
		back.Fail(c, "网络异常")
		return
	}
	isFollow := 0
	isPraise := 0
	userId := common.GetUserId(c)
	if userId > 0 {
		userFollow := (&user.UserFollow{}).GetByUserIdAndFollowId(userId, liveItem.UserId)
		if userFollow.Id > 0 && userFollow.IsDel == 0 {
			isFollow = 1
		}

		userLivePraise := (&user.UserLivePraise{}).GetPraiseByUserIdAndLiveItemId(userId, liveItem.Id)
		if userLivePraise.Id > 0 {
			isPraise = 1
		}
	}

	liveData := (&live2.LiveData{}).GetByLiveItemId(liveItem.Id)

	itemGoods := (&live2.LiveGoods{}).GetGoodsByLiveItemId(liveItem.Id)
	goodsIds := []uint{}
	for _, item := range itemGoods {
		goodsIds = append(goodsIds, item.GoodsId)
	}
	goodsInfos, err := recook.Goods.GetListByIds(goodsIds)
	if err != nil {
		back.Fail(c, "网络异常")
		return
	}
	goodsInfoMap := map[uint]recook.GoodsInfo{}
	for _, info := range *goodsInfos {
		goodsInfoMap[info.ID] = info
	}
	goodsList := []GoodsItem{}
	for _, item := range itemGoods {
		goodsList = append(goodsList, GoodsItem{
			GoodsInfo: goodsInfoMap[item.GoodsId],
		})
	}

	reply := replyLiveInfo{
		Nickname:     (*users)[0].Nickname,
		HeadImgUrl:   (*users)[0].HeadImgUrl,
		InvitationNo: (*users)[0].InvitationNo,
		PlayUrl:      liveItem.VideoUrl,
		UserId:       liveItem.UserId,
		Id:           liveItem.Id,
		Cover:        liveItem.Cover,
		IsFollow:     isFollow,
		IsPraise:     isPraise,
		Praise:       liveData.Praise,
		GoodsLists:   goodsList,
	}
	back.Suc(c, "操作成功", reply)
}

type argsExplain struct {
	LiveItemId uint `json:"liveItemId" form:"liveItemId"`
	GoodsId    uint `json:"goodsId" form:"goodsId"`
}

// @Title 讲解
func (l *Live) Explain(c *gin.Context) {
	args := argsExplain{}
	if err := tools.ParseParams(&args, c); err != nil {
		back.Fail(c, err.Error())
		return
	}
	if args.LiveItemId <= 0 || args.GoodsId <= 0 {
		back.Fail(c, "参数错误")
		return
	}
	userId := common.GetUserId(c)
	liveItem := (&live2.LiveItem{}).FindById(args.LiveItemId)
	if liveItem.Id <= 0 || liveItem.UserId != userId {
		back.Fail(c, "参数错误")
		return
	}
	liveGoods := &live2.LiveGoods{}
	liveGoods.UnExplain(args.LiveItemId)
	liveGoods.Explain(args.LiveItemId, args.GoodsId)

	live.ImLogic.SendLiveGroupMessage(liveItem.RoomId, live.LiveGroupMsgTypeExplain, gin.H{
		"goodsId": args.GoodsId,
	})

	back.Suc(c, "操作成功", nil)
}

// @Title 取消讲解
func (l *Live) UnExplain(c *gin.Context) {
	args := argsExplain{}
	if err := tools.ParseParams(&args, c); err != nil {
		back.Fail(c, err.Error())
		return
	}
	if args.LiveItemId <= 0 || args.GoodsId <= 0 {
		back.Fail(c, "参数错误")
		return
	}
	userId := common.GetUserId(c)
	liveItem := (&live2.LiveItem{}).FindById(args.LiveItemId)
	if liveItem.Id <= 0 || liveItem.UserId != userId {
		back.Fail(c, "参数错误")
		return
	}
	liveGoods := &live2.LiveGoods{}
	liveGoods.UnExplain(args.LiveItemId)

	live.ImLogic.SendLiveGroupMessage(liveItem.RoomId, live.LiveGroupMsgTypeUnExplain, gin.H{
		"goodsId": args.GoodsId,
	})
	back.Suc(c, "操作成功", nil)
}

type argsStop struct {
	LiveItemId uint `json:"liveItemId" form:"liveItemId"`
}

type replyStop struct {
	Nickname           string          `json:"nickname"`
	HeadImgUrl         string          `json:"headImgUrl"`
	Duration           int             `json:"duration"`
	SalesVolume        decimal.Decimal `json:"salesVolume"`
	MonthDuration      int             `json:"monthDuration"`
	AnticipatedRevenue decimal.Decimal `json:"anticipatedRevenue"`
	Buy                int             `json:"buy"`
	Look               int             `json:"look"`
	Praise             int             `json:"praise"`
	Fans               int             `json:"'fans'"`
}

// @Title 结束直播
func (l *Live) Stop(c *gin.Context) {
	args := argsStop{}
	if err := tools.ParseParams(&args, c); err != nil {
		back.Fail(c, err.Error())
		return
	}
	if args.LiveItemId <= 0 {
		back.Fail(c, "参数错误")
		return
	}
	userId := common.GetUserId(c)
	if err := live.LiveLogic.Stop(userId, args.LiveItemId); err != nil {
		back.Fail(c, err.Error())
		return
	}
	result := live.LiveLogic.GetLiveInfo(userId, args.LiveItemId)
	back.Suc(c, "操作成功", result)
}

type argsTranscribe struct {
	LiveItemId uint `json:"liveItemId" form:"liveItemId"`
}

// @Title 保存录制
func (l *Live) Transcribe(c *gin.Context) {
	args := argsTranscribe{}
	if err := tools.ParseParams(&args, c); err != nil {
		back.Fail(c, err.Error())
		return
	}
	if args.LiveItemId <= 0 {
		back.Fail(c, "参数错误")
		return
	}
	if err := live.LiveLogic.Transcribe(args.LiveItemId); err != nil {
		back.Fail(c, err.Error())
		return
	}
	back.Suc(c, "操作成功", "")
}

type argsUserData struct {
	Identifiers []string `json:"identifiers" form:"identifiers"`
}

type replyUserData struct {
	Identifier string `json:"identifier"`
	UserId     uint   `json:"userId"`
	Follow     uint   `json:"follow"`
	Fans       uint   `json:"fans"`
	IsFollow   int    `json:"isFollow"`
}

// @Title 根据im获取用户数据
func (l *Live) UserData(c *gin.Context) {
	args := argsUserData{}
	if err := tools.ParseParams(&args, c); err != nil {
		back.Fail(c, err.Error())
		return
	}
	if len(args.Identifiers) == 0 {
		back.Fail(c, "参数错误")
		return
	}
	userId := common.GetUserId(c)
	spectatorIds := []uint{}
	for _, identifier := range args.Identifiers {
		if strings.HasPrefix(identifier, "recook_") {
			spectatorId, _ := strconv.ParseUint(identifier[7:], 10, 64)
			spectatorIds = append(spectatorIds, uint(spectatorId))
		}
	}
	reply := []replyUserData{}
	userDataMap := map[uint]user.UserData{}
	userFollowMap := map[uint]user.UserFollow{}
	if len(spectatorIds) > 0 {
		userDatas := (&user.UserData{}).GetByUserIds(spectatorIds)
		for _, data := range userDatas {
			userDataMap[data.UserId] = data
		}
		userFollows := (&user.UserFollow{}).GetByUserIdAndFollowIds(userId, spectatorIds)
		for _, follow := range userFollows {
			userFollowMap[follow.FollowUserId] = follow
		}
	}
	for _, identifier := range args.Identifiers {
		if strings.HasPrefix(identifier, "recook_") {
			spectatorId, _ := strconv.ParseUint(identifier[7:], 10, 64)
			isFollow := 0
			if _, ok := userFollowMap[uint(spectatorId)]; ok {
				isFollow = 1
			}
			reply = append(reply, replyUserData{
				Identifier: identifier,
				Fans:       userDataMap[uint(spectatorId)].Fans,
				IsFollow:   isFollow,
				Follow:     userDataMap[uint(spectatorId)].Follows,
				UserId:     userDataMap[uint(spectatorId)].UserId,
			})
		} else {
			reply = append(reply, replyUserData{
				Identifier: identifier,
			})
		}
	}
	back.Suc(c, "操作成功", reply)
}
