package user

import (
	"fmt"
	"github.com/gin-gonic/gin"
	"live/app/common"
	"live/app/lib"
	"live/app/lib/back"
	"live/app/lib/recook"
	"live/app/lib/tools"
	live2 "live/app/logic/live"
	"live/app/logic/user"
	"live/app/model/live"
)

type Follow struct {
}

type argsList struct {
	FindUserId uint `json:"findUserId" form:"findUserId"`
	lib.Page
}

// @Title 会员关注列表
// @Param FindUserId uint true "需要查询的会员id"
func (f *Follow) List(c *gin.Context) {
	uid := common.GetUserId(c)
	args := argsList{}
	if err := tools.ParseParams(&args, c); err != nil {
		back.Fail(c, err.Error())
		return
	}
	if args.FindUserId <= 0 {
		back.Fail(c, "参数错误")
		return
	}
	list, count := (&user.Follow{}).GetList(uid, args.FindUserId, args.Page)

	back.Suc(c, "操作成功", gin.H{
		"list":  list,
		"total": count,
	})
}

type argsFollowChange struct {
	FollowUserId uint `json:"followUserId" form:"followUserId"`
	LiveItemId   uint `json:"liveItemId" form:"liveItemId"`
}

// @Title 添加关注
func (f *Follow) Add(c *gin.Context) {
	uid := common.GetUserId(c)
	if uid == 0 {
		back.Fail(c, "未登录")
		return
	}
	args := argsFollowChange{}
	if err := tools.ParseParams(&args, c); err != nil {
		back.Fail(c, err.Error())
		return
	}
	if args.FollowUserId <= 0 {
		back.Fail(c, "参数错误")
		return
	}
	flag := (&user.Follow{}).Add(uid, args.FollowUserId)
	if flag {
		if args.LiveItemId > 0 {
			// 直播间通知
			liveItem := (&live.LiveItem{}).FindById(args.LiveItemId)
			if liveItem.Id > 0 {
				users, _ := recook.User.GetUsers([]uint{uid})
				if len(*users) > 0 {
					live2.ImLogic.SendLiveGroupMessage(liveItem.RoomId, live2.LiveGroupMsgTypeNotice, gin.H{
						"content": fmt.Sprintf("会员%s关注了主播", (*users)[0].Nickname),
					})
				}
			}
		}
		back.Suc(c, "关注成功", "")
		return
	} else {
		back.Fail(c, "关注失败")
	}
}

// @Title 取消关注
func (f *Follow) Cancel(c *gin.Context) {
	uid := common.GetUserId(c)
	if uid == 0 {
		back.Fail(c, "未登录")
		return
	}
	args := argsFollowChange{}
	if err := tools.ParseParams(&args, c); err != nil {
		back.Fail(c, err.Error())
		return
	}
	if args.FollowUserId <= 0 {
		back.Fail(c, "参数错误")
		return
	}
	flag := (&user.Follow{}).Cancel(uid, args.FollowUserId)
	if flag {
		back.Suc(c, "取关成功", "")
		return
	} else {
		back.Fail(c, "取关失败")
	}
}
