package recook

import (
	"encoding/json"
	"errors"
	"github.com/mitchellh/mapstructure"
	"live/app/lib/client"
	"live/app/lib/config"
	"net/url"
)

const (
	resSuc  = "SUCCESS"
	resFail = "FAIL"
)

type recookClient struct {
	url string
}

var RecookClient *recookClient

func init() {
	RecookClient = &recookClient{
		url: config.Config.Section("recook").Key("url").String(),
	}
}

type request struct {
	Code string `json:"code"`
	Msg  string `json:"msg"`
	Data struct {
		Code string      `json:"code"`
		Msg  string      `json:"msg"`
		Data interface{} `json:"data"`
	} `json:"data"`
}

func (r *recookClient) Exec(action string, data url.Values, result interface{}, header ...map[string]string) error {
	resBuf, err := client.RequestFormData(r.url+action, data, header...)
	if err != nil {
		return err
	}
	requestStruct := &request{}
	err = json.Unmarshal(resBuf, requestStruct)
	if err != nil {
		return err
	}
	if requestStruct.Code != resSuc {
		return errors.New(requestStruct.Msg)
	}
	if requestStruct.Data.Code != resSuc {
		return errors.New(requestStruct.Data.Msg)
	}
	if err := mapstructure.WeakDecode(requestStruct.Data.Data, result); err != nil {
		return err
	}
	return nil
}
