package live

import (
	"errors"
	"github.com/gin-gonic/gin"
	"live/app/lib/config"
	live2 "live/app/model/live"
	"live/app/model/user"
)

type Praise struct {
}

var (
	maxPraise = config.Config.Section("live").Key("maxPraise").MustUint(3000)
)

// @Title 点赞
func (p *Praise) AddPraise(userId, liveItemId, praise uint) (err error) {
	// 验证动态数据
	info := (&live2.LiveItem{}).FindById(liveItemId)
	if info.Id <= 0 {
		return errors.New("参数错误")
	}
	userLivePraise := &user.UserLivePraise{}
	trendPraise := userLivePraise.GetPraiseByUserIdAndLiveItemId(userId, liveItemId)
	if trendPraise.Id > 0 && trendPraise.Praise >= maxPraise {
		// 已经点赞，无需处理
		return
	}
	tx := userLivePraise.Begin()
	defer func() {
		if err != nil {
			tx.Rollback()
		} else {
			tx.Commit()
		}
	}()

	if trendPraise.Id > 0 {
		row := userLivePraise.AddPraise(userId, liveItemId, praise, maxPraise)
		if row <= 0 {
			return errors.New("点赞失败")
		}
	} else {
		// 从没点赞
		row := userLivePraise.CreatePraise(userId, liveItemId, praise)
		if row <= 0 {
			return errors.New("点赞失败")
		}
	}

	// 动态数据统计
	liveData := live2.LiveData{}
	liveData.SetDb(tx)
	row := liveData.AddPraise(liveItemId, praise)
	if row <= 0 {
		return errors.New("点赞失败")
	}

	userData := &user.UserData{}
	userData.SetDb(tx)

	// 被点赞人统计数据
	row = userData.AddPraise(info.UserId, praise)
	if row <= 0 {
		return errors.New("点赞失败")
	}

	// 发送广播
	ImLogic.SendLiveGroupMessage(info.RoomId, LiveGroupMsgTypePraise, gin.H{
		"praise":    trendPraise.Praise + praise,
		"addPraise": praise,
	})
	return
}
