package trend

import (
	"errors"
	"github.com/golangkit/formatime"
	"live/app/lib"
	"live/app/lib/recook"
	"live/app/logic/topic"
	user2 "live/app/logic/user"
	"live/app/model/short"
	"live/app/model/user"
)

type Comment struct {
}

type CommentItem struct {
	recook.ReplyUserItem
	Id           uint             `json:"id" form:"id"`
	CreatedAt    formatime.Second `json:"createdAt" form:"createdAt"`
	Content      string           `json:"content" form:"content"`
	CommentCount uint             `json:"commentCount" form:"commentCount"`
	Praise       uint             `json:"praise" form:"praise"`
	IsPraise     int              `json:"isPraise"`
}

type CommentList struct {
	CommentItem
	Sub []CommentItem `json:"sub" form:"sub"`
}

// @Title 获取评论列表
func (c *Comment) List(userId, trendId, parentId uint, page lib.Page) (result *[]CommentList, count int64) {
	result = &[]CommentList{}
	userTrendComment := &user.UserTrendComment{}
	start := (page.GetPage() - 1) * page.GetLimit()
	count = userTrendComment.GetCountByUserId(trendId, parentId)
	if count <= int64(start) {
		// 没有数据，不需要查库
		return
	}
	commentLists := userTrendComment.GetListByTrendId(trendId, parentId, start, page.GetLimit())
	commentIds := []uint{}
	userIds := []uint{}
	for _, comment := range *commentLists {
		// 每条评论中显示一条回复
		commentIds = append(commentIds, comment.Id)
		userIds = append(userIds, comment.UserId)
	}
	sonLists := userTrendComment.GetFirstByParentIds(commentIds)
	sonMap := map[uint]user.UserTrendComment{}
	sonIds := []uint{}
	for _, son := range *sonLists {
		sonMap[son.ParentId] = son
		userIds = append(userIds, son.UserId)
		sonIds = append(sonIds, son.Id)
	}

	// 获取会员头像昵称
	users, _ := recook.User.GetUsers(userIds)
	userMap := map[uint]recook.ReplyUserItem{}
	for _, item := range *users {
		userMap[item.UserId] = item
	}

	// 判断会员是否点赞
	userPraiseMap := map[uint]user.UserTrendCommentPraise{}
	if userId > 0 {
		userTrendCommentPraise := &user.UserTrendCommentPraise{}
		userPraises := userTrendCommentPraise.GetPraiseByUserIdAndCommentIds(userId, append(commentIds, sonIds...))
		for _, userPraise := range userPraises {
			userPraiseMap[userPraise.CommentId] = userPraise
		}
	}

	for _, comment := range *commentLists {
		sub := []CommentItem{}
		isPraise := 0
		if _, ok := userPraiseMap[comment.Id]; ok {
			isPraise = 1
		}
		if subItem, ok := sonMap[comment.Id]; ok {
			subIsPraise := 0
			if _, ok := userPraiseMap[subItem.Id]; ok {
				subIsPraise = 1
			}
			sub = append(sub, CommentItem{
				ReplyUserItem: userMap[subItem.UserId],
				Id:            subItem.Id,
				CreatedAt:     subItem.CreatedAt,
				Content:       subItem.Content,
				CommentCount:  subItem.CommentCount,
				Praise:        subItem.Praise,
				IsPraise:      subIsPraise,
			})
		}
		*result = append(*result, CommentList{
			CommentItem: CommentItem{
				ReplyUserItem: userMap[comment.UserId],
				Id:            comment.Id,
				CreatedAt:     comment.CreatedAt,
				Content:       comment.Content,
				CommentCount:  comment.CommentCount,
				Praise:        comment.Praise,
				IsPraise:      isPraise,
			},
			Sub: sub,
		})
	}
	return
}

// @Title 添加评论
func (c *Comment) Add(userId, trendId, parentId uint, content string) (err error) {
	info := recook.Trend.Info(trendId)
	if info.Id <= 0 || info.IsShow == 0 {
		return errors.New("无法评论")
	}
	userTrendComment := &user.UserTrendComment{}
	if parentId > 0 {
		// 开启事物
		userTrendComment.Begin()
		defer func() {
			if err == nil {
				userTrendComment.Commit()
			} else {
				userTrendComment.Rollback()
			}
		}()
		row := userTrendComment.AddComment(parentId)
		if row <= 0 {
			return errors.New("评论失败")
		}
	}
	if info.TrendType == user2.TREND_TYPE_short {
		// 短视频话题处理
		shortModel := &short.Short{}
		shortInfo := shortModel.GetInfoById(info.OriginId)
		if shortInfo.TopicId > 0 {
			// 参与人数统计
			result := (&topic.Substance{}).AddSubstance(userId, shortInfo.TopicId, userTrendComment.GetDb())
			if !result {
				return errors.New("网络异常")
			}
		}
	}

	id := userTrendComment.Create(&user.UserTrendComment{
		UserId:   userId,
		ParentId: parentId,
		Content:  content,
		TrendId:  trendId,
	})
	if id <= 0 {
		return errors.New("网络异常")
	}
	return
}

// @Title 点赞
func (c *Comment) AddPraise(userId, commentId uint) (err error) {
	// 验证动态数据
	userTrendCommentModel := &user.UserTrendComment{}
	info := userTrendCommentModel.GetById(commentId)
	if info.Id <= 0 {
		return errors.New("参数错误")
	}
	userTrendCommentPraise := &user.UserTrendCommentPraise{}
	trendPraise := userTrendCommentPraise.GetPraiseByUserIdAndCommentId(userId, commentId)
	if trendPraise.Id > 0 && trendPraise.IsDel == 0 {
		// 已经点赞，无需处理
		return
	}
	tx := userTrendCommentPraise.Begin()
	defer func() {
		if err != nil {
			tx.Rollback()
		} else {
			tx.Commit()
		}
	}()

	if trendPraise.Id > 0 {
		// 之前点赞过
		if trendPraise.IsDel == 1 {
			// 点赞后又取消了点赞
			row := userTrendCommentPraise.RenewPraise(userId, commentId)
			if row <= 0 {
				return errors.New("点赞失败")
			}
		} else {
			return
		}
	} else {
		// 从没点赞
		row := userTrendCommentPraise.AddPraise(userId, commentId)
		if row <= 0 {
			return errors.New("点赞失败")
		}
	}

	// 动态数据统计
	userTrendComment := user.UserTrendComment{}
	userTrendComment.SetDb(tx)
	row := userTrendComment.AddPraise(commentId)
	if row <= 0 {
		return errors.New("点赞失败")
	}

	userData := &user.UserData{}
	userData.SetDb(tx)

	// 被点赞人统计数据
	row = userData.AddPraise(info.UserId, 1)
	if row <= 0 {
		return errors.New("点赞失败")
	}
	return
}

// @Title 取消点赞
func (c *Comment) CancelPraise(userId, commentId uint) (err error) {
	// 验证动态数据
	userTrendCommentModel := &user.UserTrendComment{}
	info := userTrendCommentModel.GetById(commentId)
	if info.Id <= 0 {
		return errors.New("参数错误")
	}
	userTrendCommentPraise := &user.UserTrendCommentPraise{}
	trendPraise := userTrendCommentPraise.GetPraiseByUserIdAndCommentId(userId, commentId)
	if trendPraise.Id == 0 || trendPraise.IsDel == 1 {
		// 未点赞，无需处理
		return
	}
	tx := userTrendCommentPraise.Begin()
	defer func() {
		if err != nil {
			tx.Rollback()
		} else {
			tx.Commit()
		}
	}()

	row := userTrendCommentPraise.CancelPraise(userId, commentId)
	if row <= 0 {
		return errors.New("取消点赞失败")
	}
	// 动态数据统计
	userTrendComment := &user.UserTrendComment{}
	row = userTrendComment.CancelPraise(commentId)
	if row <= 0 {
		return errors.New("取消点赞失败")
	}

	userData := &user.UserData{}
	userData.SetDb(tx)

	// 被点赞人统计数据
	row = userData.CancelPraise(info.UserId)
	if row <= 0 {
		return errors.New("取消点赞失败")
	}
	return
}
