package trend

import (
	"errors"
	"live/app/lib/recook"
	"live/app/model/user"
)

type Praise struct {
}

// @Title 点赞
func (p *Praise) AddPraise(userId, trendId uint) (err error) {
	// 验证动态数据
	info := recook.Trend.Info(trendId)
	if info.UserId <= 0 {
		return errors.New("参数错误")
	}
	userTrendPraise := &user.UserTrendPraise{}
	trendPraise := userTrendPraise.GetPraiseByUserIdAndTrendId(userId, trendId)
	if trendPraise.Id > 0 && trendPraise.IsDel == 0 {
		// 已经点赞，无需处理
		return
	}
	tx := userTrendPraise.Begin()
	defer func() {
		if err != nil {
			tx.Rollback()
		} else {
			tx.Commit()
		}
	}()

	if trendPraise.Id > 0 {
		// 之前点赞过
		if trendPraise.IsDel == 1 {
			// 点赞后又取消了点赞
			row := userTrendPraise.RenewPraise(userId, trendId)
			if row <= 0 {
				return errors.New("点赞失败")
			}
		} else {
			return
		}
	} else {
		// 从没点赞
		row := userTrendPraise.AddPraise(userId, trendId)
		if row <= 0 {
			return errors.New("点赞失败")
		}
	}

	// 动态数据统计
	userTrendData := user.UserTrendData{}
	userTrendData.SetDb(tx)
	row := userTrendData.AddPraise(trendId)
	if row <= 0 {
		return errors.New("点赞失败")
	}

	userData := &user.UserData{}
	userData.SetDb(tx)

	// 被点赞人统计数据
	row = userData.AddPraise(info.UserId, 1)
	if row <= 0 {
		return errors.New("点赞失败")
	}
	return
}

// @Title 取消点赞
func (p *Praise) CancelPraise(userId, trendId uint) (err error) {
	// 验证动态数据
	info := recook.Trend.Info(trendId)
	if info.UserId <= 0 {
		return errors.New("参数错误")
	}
	userTrendPraise := &user.UserTrendPraise{}
	trendPraise := userTrendPraise.GetPraiseByUserIdAndTrendId(userId, trendId)
	if trendPraise.Id == 0 || trendPraise.IsDel == 1 {
		// 未点赞，无需处理
		return
	}
	tx := userTrendPraise.Begin()
	defer func() {
		if err != nil {
			tx.Rollback()
		} else {
			tx.Commit()
		}
	}()

	row := userTrendPraise.CancelPraise(userId, trendId)
	if row <= 0 {
		return errors.New("取消点赞失败")
	}
	// 动态数据统计
	userTrendData := &user.UserTrendData{}
	row = userTrendData.CancelPraise(trendId)
	if row <= 0 {
		return errors.New("取消点赞失败")
	}

	userData := &user.UserData{}
	userData.SetDb(tx)

	// 被点赞人统计数据
	row = userData.CancelPraise(info.UserId)
	if row <= 0 {
		return errors.New("取消点赞失败")
	}
	return
}
