package live

import (
	"github.com/shopspring/decimal"
	"gorm.io/gorm"
	"live/app/lib/db"
)

type LiveData struct {
	db.BaseModel
	Id                 uint            `gorm:"column:id" json:"id"`
	UserId             uint            `gorm:"column:user_id" json:"userId"`
	LiveItemId         uint            `gorm:"column:live_item_id" json:"liveItemId"`
	Look               int             `gorm:"column:look" json:"look"`
	Praise             int             `gorm:"column:praise" json:"praise"`
	Fans               int             `gorm:"column:fans" json:"fans"`
	Buy                int             `gorm:"column:buy" json:"buy"`
	SalesVolume        decimal.Decimal `gorm:"column:sales_volume" json:"salesVolume"`
	AnticipatedRevenue decimal.Decimal `gorm:"column:anticipated_revenue" json:"anticipatedRevenue"`
	Duration           int             `gorm:"column:duration" json:"duration"`
}

// 插入
func (l *LiveData) Create(liveData *LiveData) uint {
	l.GetDb().Create(liveData)
	if liveData.Id > 0 {
		return liveData.Id
	}
	return 0
}

// @Title 批量获取直播信息
func (l *LiveData) GetByLiveItemIds(liveItemIds []uint) (result []LiveData) {
	l.GetDb().Model(&LiveData{}).Find(&result, "live_item_id in (?)", liveItemIds)
	return
}

// @Title 批量获取直播信息
func (l *LiveData) GetByLiveItemId(liveItemId uint) (result LiveData) {
	l.GetDb().Model(&LiveData{}).First(&result, "live_item_id = ?", liveItemId)
	return
}

// @Title 新增赞
func (l *LiveData) AddPraise(liveItemId, praise uint) int64 {
	if liveItemId <= 0 {
		return 0
	}
	return l.GetDb().Model(l).Where(&LiveData{}).Where("live_item_id = ?", liveItemId).Update("praise", gorm.Expr("praise + ?", praise)).RowsAffected
}

// @Title 新增观看人数
func (l *LiveData) AddLook(liveItemId uint) int64 {
	if liveItemId <= 0 {
		return 0
	}
	return l.GetDb().Model(l).Where(&LiveData{}).Where("live_item_id = ?", liveItemId).Update("look", gorm.Expr("look + ?", 1)).RowsAffected
}

// @Title 取消赞
func (l *LiveData) CancelPraise(liveItemId uint) int64 {
	if liveItemId == 0 {
		return 0
	}
	return l.GetDb().Model(l).Where(&LiveData{}).Where("live_item_id = ?", liveItemId).Update("praise", gorm.Expr("praise - ?", 1)).RowsAffected
}

func (l *LiveData) UpdateByLiveItemId(liveItemId uint, data *LiveData) {
	l.GetDb().Model(&LiveData{}).Where("live_item_id = ?", liveItemId).Updates(data)
}

type sumDuration struct {
	SumDuration int `gorm:"column:sumDuration" json:"sumDuration"`
}

// @Title 统计月直播时长
func (l *LiveData) SumDuration(liveItemIds []uint) int {
	result := sumDuration{}
	l.GetDb().Model(&LiveData{}).Select("sum(duration) sumDuration").Where("live_item_id in (?)", liveItemIds).First(&result)
	return result.SumDuration
}
