package live

import (
	"github.com/golangkit/formatime"
	"live/app/lib/db"
)

const (
	LIVE_STATUS_finish = 0 // 已完成直播
	LIVE_STATUS_ing    = 1 // 直播中

	LIVE_Transcribe_Type_none   = 0 // 不录制
	LIVE_Transcribe_Type_ing    = 1 // 录制中
	LIVE_Transcribe_Type_finish = 2 // 录制完成
)

type LiveItem struct {
	db.BaseModel
	Id             uint             `gorm:"column:id" json:"id"`
	UserId         uint             `gorm:"column:user_id" json:"userId"`
	RoomId         uint             `gorm:"column:room_id" json:"roomId"`
	MainGoodsId    uint             `gorm:"column:main_goods_id" json:"mainGoodsId"`
	GoodsCount     uint             `gorm:"column:goods_count" json:"goodsCount"`
	Title          string           `gorm:"column:title" json:"title"`
	Cover          string           `gorm:"column:cover" json:"cover"`
	Topic          uint             `gorm:"column:topic" json:"topic"`
	Status         int              `gorm:"column:status" json:"status"`
	CreatedAt      formatime.Second `gorm:"column:created_at" json:"createdAt"`
	UpdatedAt      formatime.Second `gorm:"column:updated_at" json:"updatedAt"`
	StartAt        formatime.Second `gorm:"column:start_at" json:"startAt"`
	EndAt          formatime.Second `gorm:"column:end_at" json:"endAt"`
	FileId         string           `gorm:"column:file_id" json:"fileId"`
	VideoUrl       string           `gorm:"column:video_url" json:"videoUrl"`
	Fans           uint             `gorm:"column:fans" json:"fans"`
	TranscribeType int              `gorm:"column:transcribe_type" json:"transcribeType"`
}

// 插入
func (l *LiveItem) Create(liveItem *LiveItem) uint {
	l.GetDb().Create(liveItem)
	if liveItem.Id > 0 {
		return liveItem.Id
	}
	return 0
}

// @Title 当前直播列表
func (l *LiveItem) Lists(start, limit int) (result []LiveItem) {
	l.GetDb().Model(&LiveItem{}).Where("status = ? or transcribe_type = ?", LIVE_STATUS_ing, LIVE_Transcribe_Type_finish).Offset(start).Limit(limit).Order("id desc").Find(&result)
	return
}

// @Title 当前直播场次信息
func (l *LiveItem) FindById(id uint) (result LiveItem) {
	l.GetDb().First(&result, "id = ?", id)
	return
}

// @Title 当前直播场次信息
func (l *LiveItem) UpdateById(id uint, data map[string]interface{}) (result LiveItem) {
	l.GetDb().Model(&LiveItem{Id: id}).Updates(data)
	return
}

// @Title 当前直播场次信息
func (l *LiveItem) GetListByTime(userId uint, startTime, endTime formatime.Second) (result []LiveItem) {
	l.GetDb().Model(&LiveItem{}).Find(&result, "user_id = ? and start_at between ? and ?", userId, startTime, endTime)
	return
}

// @Title 当前直播场次信息
func (l *LiveItem) GetUserListFinish(userId uint, start, limit int) (result []LiveItem) {
	l.GetDb().Model(&LiveItem{}).Find(&result, "user_id = ? and `status` = ?", userId, LIVE_STATUS_finish)
	return
}

// @Title 当前直播场次信息
func (l *LiveItem) GetUserListTotal(userId uint) (result int64) {
	l.GetDb().Model(&LiveItem{}).Where("user_id = ? and (`status` = ? or `transcribe_type` = ?) ", userId, LIVE_STATUS_finish, LIVE_Transcribe_Type_finish).Count(&result)
	return
}

// @Title 当前直播场次信息
func (l *LiveItem) GetUserList(userId uint, start, limit int) (result []LiveItem) {
	l.GetDb().Model(&LiveItem{}).Order("id desc").Offset(start).Limit(limit).Find(&result, "user_id = ? and (`status` = ? or `transcribe_type` = ?) ", userId, LIVE_STATUS_finish, LIVE_Transcribe_Type_finish)
	return
}

// @Title 获取
func (l *LiveItem) GetUsersLiveItem(userIds []uint) (result []LiveItem) {
	if len(userIds) == 0 {
		return
	}
	l.GetDb().Model(&LiveItem{}).Find(&result, "user_id in (?) and `status` = ?", userIds, LIVE_STATUS_ing)
	return
}

// @Title 获取当前用户正在直播数据
func (l *LiveItem) GetLiveItemIng(userId uint) (result LiveItem) {
	l.GetDb().Model(&LiveItem{}).First(&result, "user_id = ? and `status` = ?", userId, LIVE_STATUS_ing)
	return
}

// @Title 更改录播状态
func (l *LiveItem) Transcribe(liveItemId uint, transcribeType int) int64 {
	return l.GetDb().Model(&LiveItem{}).Where("id = ?", liveItemId).Update("transcribe_type", transcribeType).RowsAffected
}
