package topic

import (
	"github.com/golangkit/formatime"
	"live/app/lib/db"
)

type TopicFollow struct {
	db.BaseModel
	Id        uint             `gorm:"column:id" json:"id"`
	UserId    uint             `gorm:"column:user_id" json:"userId"`
	TopicId   uint             `gorm:"column:topic_id" json:"topicId"`
	CreatedAt formatime.Second `gorm:"column:created_at" json:"createdAt"`
	UpdatedAt formatime.Second `gorm:"column:updated_at" json:"updatedAt"`
	IsDel     int              `gorm:"column:is_del" json:"isDel"`
}

// 插入
func (t *TopicFollow) Create(topicFollow *TopicFollow) uint {
	t.GetDb().Create(topicFollow)
	if topicFollow.Id > 0 {
		return topicFollow.Id
	}
	return 0
}

// @Title 通过会员id获取关注列表
// @Param userId uint true "会员id"
func (t *TopicFollow) GetListByUserId(userId uint, start, limit int) *[]TopicFollow {
	if userId <= 0 {
		return &[]TopicFollow{}
	}
	userFollow := []TopicFollow{}
	t.GetDb().Model(t).Where(TopicFollow{UserId: userId}).Where("is_del = ?", 0).Limit(limit).Offset(start).Order("id desc").Find(&userFollow)
	return &userFollow
}

// 获取会员关注数量
func (t *TopicFollow) GetCountByUserId(userId uint) (result int64) {
	if userId <= 0 {
		return
	}
	t.GetDb().Model(t).Where(TopicFollow{UserId: userId}).Where("is_del = ?", 0).Count(&result)
	return
}

// 获取会员关注的关注信息
func (t *TopicFollow) GetByUserIdAndTopicIds(userId uint, topicIds []uint) (result []TopicFollow) {
	if userId == 0 || len(topicIds) == 0 {
		return
	}
	t.GetDb().Model(t).Find(&result, "user_id = ? and topic_id in (?) and is_del = 0", userId, topicIds)
	return
}

// 获取会员关注的单个关注信息
func (t *TopicFollow) GetByUserIdAndTopicId(userId uint, topicId uint) (result TopicFollow) {
	if userId == 0 || topicId == 0 {
		return
	}
	t.GetDb().Model(t).First(&result, "user_id = ? and topic_id = ?", userId, topicId)
	return
}

// @Title 取消关注
func (t *TopicFollow) CancelFollow(userId, topicId uint) int64 {
	if userId == 0 || topicId == 0 {
		return 0
	}
	return t.GetDb().Model(t).Where(&TopicFollow{UserId: userId, TopicId: topicId}).
		Where("is_del = ?", 0).Update("is_Del", 1).RowsAffected
}

// @Title 重新关注
func (t *TopicFollow) RenewFollow(userId, topicId uint) int64 {
	if userId == 0 || topicId == 0 {
		return 0
	}
	return t.GetDb().Model(t).Where(&TopicFollow{UserId: userId, TopicId: topicId}).
		Where("is_del = ?", 1).Update("is_Del", 0).RowsAffected
}
