package middleware

import (
	"github.com/gin-gonic/gin"
	"live/app/lib/back"
	"live/app/lib/recook"
	"strconv"
)

/*
令牌校验 中间件拦截
*/
func Auth() gin.HandlerFunc {
	return func(c *gin.Context) {
		if c.Request.Method == "GET" {
			c.Next()
		} else if c.Request.Method == "POST" {
			if len(c.Request.Header.Get("X-Recook-ID")) == 0 {
				back.Fail(c, "游客无法使用该功能，请登录")
				c.Abort()
				return
			}

			if len(c.Request.Header.Get("X-Recook-Token")) == 0 {
				back.Fail(c, "游客无法使用该功能，请登录")
				c.Abort()
				return
			}

			id, err := strconv.ParseUint(c.Request.Header.Get("X-Recook-ID"), 10, 64)
			if id <= 0 || err != nil {
				back.Fail(c, "游客无法使用该功能，请登录")
				c.Abort()
				return
			}

			token := c.Request.Header.Get("X-Recook-Token")
			userId := recook.User.GetUserId(uint(id), token)
			if userId == 0 {
				back.Unauthorized(c)
				c.Abort()
			}
			c.Set("userId", userId)
		} else {
			c.Abort()
		}
	}
}
